@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: blt2d.tcl,v 1.33 1998/12/26 10:43:44 jfontain Exp $}
+set rcsId {$Id: blt2d.tcl,v 1.34 1999/03/13 21:35:22 jfontain Exp $}
 
 class blt2DViewer {
 
@@ -9,12 +9,8 @@ class blt2DViewer {
     set blt2DViewer::(colors) {#7FFFFF #7FFF7F #FF7F7F #FFFF7F #7F7FFF #FFBF00 #BFBFBF #FF7FFF #FFFFFF}
 
     proc blt2DViewer {this path} viewer {} {
-        $path configure -cursor {}
-if {$::officialBLT} {
-        $path configure -plotpadx 2 -plotpady 2           ;# use minimum padding for extreme values and flat zero line to be visible
-        $path yaxis configure -tickshadow {}
-}
-        $path yaxis configure -title {} -tickfont $font::(smallNormal)
+        $path configure -cursor {} -plotpadx 2 -plotpady 2   ;# use minimum padding for extreme values, flat zero line to be visible
+        $path yaxis configure -tickshadow {} -title {} -tickfont $font::(smallNormal)
         $path legend configure -borderwidth 1 -font $font::(mediumNormal) -activebackground white
 
         viewer::setupDropSite $this $path                                                            ;# allow dropping of data cells
