@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: datagraf.tcl,v 1.48 1999/03/13 21:35:22 jfontain Exp $}
+set rcsId {$Id: datagraf.tcl,v 1.51 1999/04/25 12:44:35 jfontain Exp $}
 
 
 class dataGraph {
@@ -13,6 +13,10 @@ class dataGraph {
         set path $widget::($this,path)
         $path xaxis configure -tickfont $font::(smallNormal) -title {} -rotate 90 -command dataGraph::axisTime -tickshadow {}
         $path pen create void -linewidth 0 -symbol none                                                       ;# pen for void values
+        set marker [$path marker create polygon -fill {} -coords {-Inf Inf Inf Inf Inf -Inf -Inf -Inf}]
+        $path crosshairs configure -color blue
+        $path marker bind $marker <Enter> "dataGraph::enterPlotArea $path %x %y"
+        $path marker bind $marker <Leave> "dataGraph::leavePlotArea $path"
         # track size updates (do not use Configure event since it leads to incorrect values for graph internal components)
         bind $path <Visibility> "dataGraph::resized $this"
         set dataGraph::($this,plotWidth) 0                                                                       ;# cache plot width
@@ -41,15 +45,15 @@ class dataGraph {
     }
 
     proc options {this} {
-        set samples [expr {$configuration::(graphNumberOfIntervals)+1}]
+        set samples [expr {$global::graphNumberOfIntervals+1}]
         # force size and interval values
         return [list\
             [list -deletecommand {} {}]\
             [list -draggable draggable Draggable 0 0]\
-            [list -height height Height $configuration::(default,viewer,height)]\
+            [list -height height Height $global::viewerHeight]\
             [list -interval interval Interval 5]\
             [list -samples samples Samples $samples $samples]\
-            [list -width width Width $configuration::(default,viewer,width)]\
+            [list -width width Width $global::viewerWidth]\
         ]
     }
 
@@ -128,6 +132,27 @@ class dataGraph {
         }
     }
 
+    proc enterPlotArea {path x y} {
+        $path configure -cursor tcross
+        $path crosshairs on
+        bind $path <Any-Motion> "dataGraph::processMotion $path %x %y"
+        lifoLabel::push $global::messenger "[dataGraph::axisTime $path $x] $y"
+    }
+
+    proc leavePlotArea {path} {
+        $path configure -cursor {}
+        $path crosshairs off
+        bind $path <Any-Motion> {}
+        lifoLabel::pop $global::messenger
+    }
+
+    proc processMotion {path x y} {
+        $path crosshairs configure -position @$x,$y
+        foreach {x y} [$path invtransform $x $y] {}
+        lifoLabel::pop $global::messenger
+        lifoLabel::push $global::messenger "[dataGraph::axisTime $path $x] $y"
+    }
+
 }
 
 class dataGraph {
@@ -135,7 +160,7 @@ class dataGraph {
     class element {
 
         proc element {this path interval args} switched {$args} {                ;# interval is required to properly draw fist point
-            set dots [expr {$configuration::(graphNumberOfIntervals)+1}]
+            set dots [expr {$global::graphNumberOfIntervals+1}]
             # prevent BLT core dumps by working at the global level instead of the namespace level
             uplevel #0 "
                 blt::vector create xVector${this}($dots)                                                       ;# x axis data vector
