@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: gui.tcl,v 1.9 1999/03/13 21:35:22 jfontain Exp $}
+set rcsId {$Id: gui.tcl,v 1.16 1999/05/08 20:36:20 jfontain Exp $}
 
 proc updateTitle {} {                                                          ;# show modules and poll time or mode in window title
     if {[llength $global::pollTimes]==0} {
@@ -13,48 +13,124 @@ proc updateTitle {} {                                                          ;
 
 proc createMenuWidget {parentPath readOnly includePollTime} {
     set menu [menu $parentPath.menu -tearoff 0]
-    $menu add cascade -label File -menu [menu $menu.file -tearoff 0] -underline 0
+    set help(bar) [new menuContextHelp $menu]
+    set index(bar) -1
+
+    menu $menu.file -tearoff 0
+    set global::fileMenuContextHelper [new menuContextHelp $menu.file]
+    set index(file) -1
+
+    $menu add cascade -label File -menu $menu.file -underline 0
+    menuContextHelp::set $help(bar) [incr index(bar)] {file related operations}
+
     if {!$readOnly} {
         $menu.file add command -label Save -command {save 0} -underline 1 -accelerator Alt+S
         bind $parentPath <Alt-s> {save 0}
+        set string {input file for saving configuration and viewers layout}
+        set global::fileMenuContextHelperSaveIndex [incr index(file)]
+        updateFileSaveMenuHelp $global::saveFile                          ;# save file may already have been defined in command line
+
         $menu.file add command -label {Save As...} -command {save 1} -underline 6 -accelerator Alt+A
         bind $parentPath <Alt-a> {save 1}
+        menuContextHelp::set $global::fileMenuContextHelper [incr index(file)] $string
     }
+
     $menu.file add command -label Exit -command exit -underline 1 -accelerator Alt+X
+    menuContextHelp::set $global::fileMenuContextHelper [incr index(file)] {close main window and exit program}
     bind $parentPath <Alt-x> exit
-    if {!$readOnly&&$includePollTime} {
-        $menu add cascade -label Options -menu [menu $menu.options -tearoff 0] -underline 0
-        $menu.options add command -label {Poll Time...} -command inquirePollTime -underline 0
-    }
+
     if {!$readOnly} {
-        $menu add cascade -label New -menu [menu $menu.new -tearoff 0] -underline 0
-        $menu.new add command -label {Graph Chart...} -underline 0\
+        $menu add cascade -label Edit -menu [menu $menu.edit -tearoff 0] -underline 0
+        set help(edit) [new menuContextHelp $menu.edit]
+        menuContextHelp::set $help(bar) [incr index(bar)] {content editing and preferences}
+
+        $menu.edit add cascade -label New -menu [menu $menu.edit.new -tearoff 0] -underline 0
+        set help(new) [new menuContextHelp $menu.edit.new]
+        menuContextHelp::set $help(edit) 0 {create empty data viewers}
+
+        $menu.edit.new add command -label {Graph Chart...} -underline 0\
             -command "createCellsViewer dataGraph {} 1 $global::static \$global::pollTime"
-        $menu.new add command -label {Overlap Bar Chart...} -underline 0\
+        menuContextHelp::set $help(new) 0 {create an empty graph chart data viewer}
+
+        $menu.edit.new add command -label {Overlap Bar Chart...} -underline 0\
             -command "createCellsViewer dataOverlapBarChart {} 1 $global::static"
-        $menu.new add command -label {Side Bar Chart...} -underline 5\
+        menuContextHelp::set $help(new) 1 {create an empty overlap bar chart data viewer}
+
+        $menu.edit.new add command -label {Side Bar Chart...} -underline 5\
             -command "createCellsViewer dataSideBarChart {} 1 $global::static"
-        $menu.new add command -label {Stacked Bar Chart...} -underline 0\
+        menuContextHelp::set $help(new) 2 {create an empty side bar chart data viewer}
+
+        $menu.edit.new add command -label {Stacked Bar Chart...} -underline 0\
             -command "createCellsViewer dataStackedBarChart {} 1 $global::static"
-        $menu.new add command -label {2D Pie Chart...} -underline 0 -command "createCellsViewer data2DPieChart {} 1 $global::static"
-        $menu.new add command -label {3D Pie Chart...} -underline 0 -command "createCellsViewer data3DPieChart {} 1 $global::static"
-        $menu.new add command -label {Summary Table...} -underline 8 -command "createCellsViewer summaryTable {} 1 $global::static"
-        $menu.new add command -label {Free Text...} -underline 0 -command "createCellsViewer freeText {} 1 $global::static"
+        menuContextHelp::set $help(new) 3 {create an empty stacked bar chart data viewer}
+
+        $menu.edit.new add command -label {2D Pie Chart...} -underline 0\
+            -command "createCellsViewer data2DPieChart {} 1 $global::static"
+        menuContextHelp::set $help(new) 4 {create an empty 2D pie chart data viewer}
+
+        $menu.edit.new add command -label {3D Pie Chart...} -underline 0\
+            -command "createCellsViewer data3DPieChart {} 1 $global::static"
+        menuContextHelp::set $help(new) 5 {create an empty 3D pie chart data viewer}
+
+        $menu.edit.new add command -label {Summary Table...} -underline 8\
+            -command "createCellsViewer summaryTable {} 1 $global::static"
+        menuContextHelp::set $help(new) 6 {create an empty summary table data viewer}
+
+        $menu.edit.new add command -label {Free Text...} -underline 0 -command "createCellsViewer freeText {} 1 $global::static"
+        menuContextHelp::set $help(new) 7 {create an empty free text data viewer}
+
+        $menu.edit add command -label {Preferences...} -command preferences::edit -underline 0
+        menuContextHelp::set $help(edit) 1 {edit preferences and configuration}
     }
+
+    if {!$readOnly&&$includePollTime} {
+        $menu add cascade -label View -menu [menu $menu.view -tearoff 0] -underline 0
+        set help(options) [new menuContextHelp $menu.view]
+        menuContextHelp::set $help(bar) [incr index(bar)] {data visualization settings}
+
+        $menu.view add command -label {Poll Time...} -command inquirePollTime -underline 0
+        menuContextHelp::set $help(options) 0 {change poll time for all synchronous modules}
+    }
+
     $menu add cascade -label Help -menu [menu $menu.help -tearoff 0] -underline 0
+    set help(help) [new menuContextHelp $menu.help]
+    menuContextHelp::set $help(bar) [incr index(bar)] {help on moodss and modules}
+
     $menu.help add command -label Global... -underline 0 -accelerator F1 -command generalHelpWindow
     bind $parentPath <F1> generalHelpWindow
+    menuContextHelp::set $help(help) 0 {global help for moodss user}
+
     $menu.help add cascade -label Modules -menu [menu $menu.help.modules -tearoff 0] -underline 0
+    set help(modules) [new menuContextHelp $menu.help.modules]
+    set index(modules) -1
+    menuContextHelp::set $help(help) 1 {help on loaded modules}
+
     foreach module $modules::(all) {
         $menu.help.modules add command -label $module... -command "moduleHelpWindow $module"
+        menuContextHelp::set $help(modules) [incr index(modules)] "display $module module documentation"
     }
+
     $menu.help add command -label Copyright... -underline 0 -command {simpleTextDialogBox {moodss: Copyright} $help::copyright}
+    menuContextHelp::set $help(help) 2 {display copyright information}
+
     $menu.help add command -label {Source Versions...} -underline 0 -command versionsDialogBox
+    menuContextHelp::set $help(help) 3 {display all source files versions}
+
     $menu.help add command -label About... -underline 0 -command aboutDialogBox
+    menuContextHelp::set $help(help) 4 {display author and general information}
 
     $parentPath configure -menu $menu
 }
 
+proc updateFileSaveMenuHelp {file} {
+    if {[string length $file]==0} {
+        set string {input file for saving configuration and viewers layout}
+    } else {
+        set string "into $file file, save configuration and viewers layout"
+    }
+    menuContextHelp::set $global::fileMenuContextHelper $global::fileMenuContextHelperSaveIndex $string
+}
+
 proc createMessageWidget {parentPath} {
     set global::messenger [new lifoLabel $parentPath -headerfont $font::(mediumBold) -font $font::(mediumNormal)]
     return $widget::($global::messenger,path)                                                             ;# return actual tk widget
@@ -165,6 +241,8 @@ proc inquirePollTime {} {
     pack $message
     set entry [new spinEntry $frame -width 4 -list $global::pollTimes -side right]
     spinEntry::set $entry $global::pollTime
+    wcb::callback $composite::($entry,entry,path) before insert wcb::checkStrForNum                   ;# filter on positive integers
+
     pack $widget::($entry,path) -anchor e -side left -expand 1 -padx 2       ;# evenly pack entry and label together near the center
     pack [label $frame.label -text seconds] -anchor w -side right -expand 1 -padx 2
     dialogBox::display $dialog $frame
