@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: help.tcl,v 1.30 1999/03/08 18:18:52 jfontain Exp $}
+set rcsId {$Id: help.tcl,v 1.31 1999/05/07 10:24:51 jfontain Exp $}
 
 namespace eval help {
 
@@ -22,7 +22,16 @@ This program is distributed in the hope that it will be useful, but WITHOUT ANY
         jfontain@multimania.com
 
 
-This software includes the Tcl HTML library developped by Sun Microsystems and made available under the following license terms:
+This software uses the following extensions:
+
+    - the BLT library by George Howlett
+    - the tkTable widget by Jeffrey Hobbs
+    - the wcb (Widget Callback Package) library by Csaba Nemethi
+
+Thank you so very much to the authors for their great work.
+
+
+This software also includes the Tcl HTML library developped by Sun Microsystems and made available under the following license terms:
 
 Sun Microsystems, Inc.  The following terms apply to all files associated with the software unless explicitly disclaimed in individual files.
 
