@@ -12,13 +12,15 @@ proc recordRCSId {variableName empty operation} {
 }
 trace variable ::rcsId w recordRCSId                                                                ;# keep track of RCS identifiers
 
-set rcsId {$Id: moodss.tcl,v 1.158 1999/03/23 22:04:21 jfontain Exp $}
+set rcsId {$Id: moodss.tcl,v 1.168 1999/06/27 20:23:04 jfontain Exp $}
 
 
 source utility.tcl
 startGatheringPackageDirectories
 
 source global.tcl
+source preferen.tcl
+preferences::load                                                                     ;# initialize from rc file as soon as possible
 source getopt.tcl
 
 proc printUsage {exitCode} {
@@ -88,7 +90,7 @@ if {[catch {package require scwoop 2.6}]} {
     source panner.tcl
     source scroll.tcl
 }
-if {[catch {package require tkpiechart 5.2.2}]} {                                     ;# in case tkpiechart package is not installed
+if {[catch {package require tkpiechart 5.3}]} {                                       ;# in case tkpiechart package is not installed
     source pielabel.tcl
     source boxlabel.tcl
     source canlabel.tcl
@@ -102,17 +104,17 @@ if {[catch {package require tkpiechart 5.2.2}]} {
 if {[catch {package require Tktable 2}]} {                                               ;# in case tkTable package is not installed
     switch $tcl_platform(platform) {
         unix {
-            load ./Tktable.so.2.4
+            load ./Tktable.so.2.5
         }
         windows {
             load ./tktable.dll
         }
     }
 }
-if {[catch {package require BLT}]} {                                                         ;# in case BLT package is not installed
+if {[catch {package require BLT 2.4}]} {                                                     ;# in case BLT package is not installed
     switch $tcl_platform(platform) {
         unix {
-            load ./libBLT.so.2.4h
+            load ./libBLT.so.2.4i
         }
         windows {
             load ./blt24.dll
@@ -124,7 +126,6 @@ wm protocol . WM_DELETE_WINDOW exit      ;# so that closing from window manager
 wm command . [concat $argv0 $argv]                                   ;# for proper window manager (windowmaker for example) behavior
 wm group . .
 
-source config.tcl
 source font.tcl
 source lifolbl.tcl
 source gui.tcl
@@ -138,13 +139,13 @@ modules::parse $argv
 source record.tcl
 
 if {[info exists arguments(-f)]} {                                                              ;# configuration file name specified
-    set saveFile $arguments(-f)
-    set initializer [new record -file $saveFile]
+    set global::saveFile $arguments(-f)
+    set initializer [new record -file $global::saveFile]
     record::read $initializer
     modules::parse [record::modulesWithArguments $initializer]
     set modules::(initialized) [record::modules $initializer]
 } else {
-    set saveFile {}
+    set global::saveFile {}
 }
 
 wm title . {moodss: initializing modules...}
@@ -161,16 +162,22 @@ source sumtable.tcl
 source freetext.tcl
 source drag.tcl
 source drop.tcl
+source menuhelp.tcl
+source wcb.tcl
+source wcbCommon.tcl
+source wcbEntry.tcl
 
 set readOnly [info exists arguments(-r)]
 set global::static [info exists arguments(-S)]
 
 set scroll [new scroll canvas .]
 set global::canvas $composite::($scroll,scrolled,path)
-set width [winfo screenwidth .]
-set height [winfo screenheight .]
-$global::canvas configure -background white -width $width -height $height -scrollregion [list 0 0 $width $height]\
-    -highlightthickness 0 -takefocus 0
+$global::canvas configure -highlightthickness 0 -takefocus 0
+trace variable global::canvasHeight w updateCanvasSize                                       ;# track changes for good user feedback
+trace variable global::canvasWidth w updateCanvasSize
+updateCanvasSize
+trace variable global::canvasBackground w updateCanvasBackground                             ;# track changes for good user feedback
+updateCanvasBackground
 
 set global::windowManager [new canvasWindowManager $global::canvas]
 
@@ -184,8 +191,8 @@ if {[info exists ::geometry]} {
 }
 
 wm iconname . "moodss $modules::(all)"                                                            ;# give the icon a meaningful name
+image create photo applicationIcon -data [dataGraph::iconData]                                ;# use data graph icon for application
 if {[string compare $tcl_platform(platform) unix]==0} {
-    image create photo applicationIcon -data [dataGraph::iconData]                            ;# use data graph icon for application
     wm iconwindow . [toplevel .icon]
     pack [label .icon.image -image applicationIcon]
 }
@@ -244,17 +251,17 @@ proc manageViewer {viewer destroyable args} {                         ;# argumen
 }
 
 proc save {ask} {                               ;# save current configuration in user defined file or currently defined storage file
-    global saveFile
-
-    if {$ask||([string length $saveFile]==0)} {
+    if {$ask||([string length $global::saveFile]==0)} {
         set file [tk_getSaveFile\
-            -title {moodss: Save} -initialdir [pwd] -defaultextension .moo -filetypes {{{moodss data} .moo}} -initialfile $saveFile
+            -title {moodss: Save} -initialdir [pwd] -defaultextension .moo -filetypes {{{moodss data} .moo}}\
+            -initialfile $global::saveFile
         ]
         if {[string length $file]==0} return                                                                 ;# user canceled saving
-        set saveFile $file
+        updateFileSaveMenuHelp [set global::saveFile $file]
     }
-    lifoLabel::flash $global::messenger "saving in $saveFile..."        ;# flash instead of pushing as that goes too fast to be seen
-    set record [new record -file $saveFile]
+    # flash instead of pushing as that goes too fast to be seen
+    lifoLabel::flash $global::messenger "saving in $global::saveFile..."
+    set record [new record -file $global::saveFile]
     record::write $record
     delete $record
 }
@@ -302,8 +309,8 @@ foreach module $modules::(all) {
         } else {
             manageViewer $table 0 -static $global::static -setx $x -sety $y
         }
-        set x [expr {$x+$configuration::(xWindowManagerInitialOffset)}]                   ;# offset tables to achieve a nicer layout
-        set y [expr {$y+$configuration::(yWindowManagerInitialOffset)}]
+        set x [expr {$x+$global::xWindowManagerInitialOffset}]                            ;# offset tables to achieve a nicer layout
+        set y [expr {$y+$global::yWindowManagerInitialOffset}]
         incr index                                                                                      ;# next view for initializer
     }
 }
