@@ -1,14 +1,14 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: random.tcl,v 1.23 1999/01/16 20:31:02 jfontain Exp $}
+set rcsId {$Id: random.tcl,v 1.24 1999/01/17 20:14:53 jfontain Exp $}
 
 # module sample file with random data
 
 # corresponding pkgIndex.tcl file content:
 # package ifneeded random 4.0 "source [file join $dir random.tcl]"
 
-package provide random 4.1
+package provide random 4.2
 
 namespace eval random {                                                                    ;# namespace name must match package name
     # Module data is arranged in a single array that can be used by many views, such as tables, graphs, pies,...
@@ -63,7 +63,7 @@ namespace eval random {
         }
         switches {-a 0 --asynchronous 0}
     }
-    set file [open [file join $packageDirectory random.htm]]                                ;# directory is set in pkgIndex.tcl file
+    set file [open [file join $::packageDirectory(random) random.htm]]                      ;# directory is set in pkgIndex.tcl file
     set data(helpText) [read $file]                                   ;# initialize HTML help data from file in module sub-directory
     close $file
 
